@@ -2,6 +2,8 @@
 import requests
 import json
 import logging
+import pytz
+
 from requests import Session
 from datetime import datetime, timedelta
 from jsonfinder import jsonfinder
@@ -71,12 +73,17 @@ class solaredgeoptimizers:
 
         solarsite = self.requestListOfAllPanels()
 
+        lifetimeenergy = json.loads(self.getLifeTimeEnergy())
+
         data = []
         for inverter in solarsite.inverters:
             for string in inverter.strings:
                 for optimizer in string.optimizers:
                     info = self.requestSystemData(optimizer.optimizerId)
                     if info is not None:
+                        # Life time energy adding
+                        info.lifetime_energy = (float(lifetimeenergy[str(optimizer.optimizerId)]["unscaledEnergy"])) / 1000
+
                         data.append(info)
 
         return data
@@ -295,6 +302,9 @@ class SolarEdgeOptimizerData:
         self.power = ""
         self.voltage = ""
 
+        # Extra info
+        self.lifetime_energy = ""
+
         if paneelid is not None:
             self._json_obj = json_object
 
